Add flag to enable RTS based polling

RTS based polling in LAPDm code is disabled by default. Make libosmogsm
stay compatible with existing applications that do not use RTS based
polling.

This patch fixes the issue that LAPDM_ENT_F_POLLING_ONLY did enable RTS
based polling too, which breaks existing applications like older
versions of osmo-bts.

Change-Id: I2a75c192bbc24e85bfc1656b2be21cea7a92814a
diff --git a/src/gsm/lapdm.c b/src/gsm/lapdm.c
index fb892d2..1fc986d 100644
--- a/src/gsm/lapdm.c
+++ b/src/gsm/lapdm.c
@@ -363,8 +363,8 @@
 	if (le->tx_pending || le->flags & LAPDM_ENT_F_POLLING_ONLY) {
 		struct msgb *old_msg;
 
-		/* In 'Polling only' mode there can be only one message. */
-		if (le->flags & LAPDM_ENT_F_POLLING_ONLY) {
+		/* In 'RTS' mode there can be only one message. */
+		if (le->flags & LAPDM_ENT_F_RTS) {
 			/* Overwrite existing message by removing it first. */
 			if ((old_msg = msgb_dequeue(&dl->dl.tx_queue))) {
 				msgb_free(old_msg);
@@ -424,8 +424,8 @@
 {
 	struct msgb *msg;
 
-	/* Call RTS function of LAPD, to poll next frame. */
-	if (dl->entity->flags & LAPDM_ENT_F_POLLING_ONLY) {
+	/* Call RTS function of LAPD, to queue next frame. */
+	if (dl->entity->flags & LAPDM_ENT_F_RTS) {
 		struct lapd_msg_ctx lctx;
 		int rc;
 
@@ -1635,7 +1635,7 @@
 	le->flags = flags;
 
 	/* Set flags at LAPD. */
-	if (le->flags & LAPDM_ENT_F_POLLING_ONLY)
+	if (le->flags & LAPDM_ENT_F_RTS)
 		dl_flags |= LAPD_F_RTS;
 	if (le->flags & LAPDM_ENT_F_DROP_2ND_REJ)
 		dl_flags |= LAPD_F_DROP_2ND_REJ;